==> apache-cxf-3.6.10-src.zip: apache-cxf-3.6.10-src/rt/rs/extensions/reactivestreams/src/main/java/org/apache/cxf/jaxrs/reactivestreams/server/JsonStreamingAsyncSubscriber.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.jaxrs.reactivestreams.server;

import javax.ws.rs.container.AsyncResponse;

public class JsonStreamingAsyncSubscriber<T> extends StreamingAsyncSubscriber<T> {
    public JsonStreamingAsyncSubscriber(AsyncResponse ar) {
        this(ar, 1000);
    }
    public JsonStreamingAsyncSubscriber(AsyncResponse ar, long pollTimeout) {
        this(ar, pollTimeout, 0);
    }
    public JsonStreamingAsyncSubscriber(AsyncResponse ar, long pollTimeout, long asyncTimeout) {
        super(ar, "[", "]", ",", pollTimeout, asyncTimeout);
    }

    public JsonStreamingAsyncSubscriber(AsyncResponse ar, String prefix, String suffix, String separator, 
                                        long pollTimeout, long asyncTimeout) {
        super(ar, prefix, suffix, separator, pollTimeout, asyncTimeout);
    }
}

==> apache-cxf-4.2.0-src.zip: apache-cxf-4.2.0-src/rt/rs/extensions/reactivestreams/src/main/java/org/apache/cxf/jaxrs/reactivestreams/server/JsonStreamingAsyncSubscriber.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.jaxrs.reactivestreams.server;

import jakarta.ws.rs.container.AsyncResponse;

public class JsonStreamingAsyncSubscriber<T> extends StreamingAsyncSubscriber<T> {
    public JsonStreamingAsyncSubscriber(AsyncResponse ar) {
        this(ar, 1000);
    }
    public JsonStreamingAsyncSubscriber(AsyncResponse ar, long pollTimeout) {
        this(ar, pollTimeout, 0);
    }
    public JsonStreamingAsyncSubscriber(AsyncResponse ar, long pollTimeout, long asyncTimeout) {
        super(ar, "[", "]", ",", pollTimeout, asyncTimeout);
    }

    public JsonStreamingAsyncSubscriber(AsyncResponse ar, String prefix, String suffix, String separator, 
                                        long pollTimeout, long asyncTimeout) {
        super(ar, prefix, suffix, separator, pollTimeout, asyncTimeout);
    }
}
